@@ -3,3 +3,6 @@ from ...rpc.tests import * # nolint
 from ...main.tests import * # nolint
 
 from .serializer import * # nolint
+from .handler import * # nolint
+from .resource import * # nolint
+from .api import * # nolint
